@@ -1,10 +1,16 @@
-test_that("test cardSummary", {
+test_that("test summaryCard", {
   displayOutput <- function(x) {
-    x |> as.character() |> stringr::str_split_1("\n") |> cat(sep = "\n")
+    x |>
+      as.character() |>
+      stringr::str_split_1("\n") |>
+      purrr::keep(\(x) !grepl("htmlwidget-", x)) |>
+      cat(sep = "\n")
   }
 
   # empty summarised result
-  expect_no_error(x <- cardSummary(emptySummarisedResult()))
+  res <- omopgenerics::emptySummarisedResult() |>
+    prepareResult(list())
+  expect_no_error(x <- summaryCard(res))
   expect_true(inherits(x, "bslib_fragment"))
   expect_snapshot(displayOutput(x))
 
@@ -27,8 +33,9 @@ test_that("test cardSummary", {
       package_name = c("OmopViewer", "OmopViewer", "omopgenerics"),
       package_version = c("0.1.0", "0.2.0", "1.0.0"),
       min_cell_count = c(NA, 1, 5)
-    ))
-  expect_no_error(x <- cardSummary(res))
+    )) |>
+    prepareResult(list(counts = c(1, 2), sums = 3))
+  expect_no_error(x <- summaryCard(res))
   expect_true(inherits(x, "bslib_fragment"))
   expect_snapshot(displayOutput(x))
 })
